@@ -1,37 +1,39 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 #include "configure.h"
 
   /* Debugs for debug_level	*/
-#define DEBUG_SYSDEP	0x1
-#define DEBUG_MAIL		0x10
-#define DEBUG_NET		0x20
-#define DEBUG_TIMER		0x40
-#define	DEBUG_SENSORS	0x80
-#define	DEBUG_INET		0x800
-#define	DEBUG_CLIENT	0x1000
-#define DEBUG_GUI		0x2000
-#define	DEBUG_POSITION	0x4000
-#define	DEBUG_BATTERY	0x8000
+#define DEBUG_SYSDEP		0x1
+#define DEBUG_MAIL			0x10
+#define DEBUG_NET			0x20
+#define DEBUG_TIMER			0x40
+#define	DEBUG_SENSORS		0x80
+#define	DEBUG_INET			0x800
+#define	DEBUG_CLIENT		0x1000
+#define DEBUG_GUI			0x2000
+#define	DEBUG_POSITION		0x4000
+#define	DEBUG_BATTERY		0x8000
+#define	DEBUG_CHART_TEXT	0x10000
+#define	DEBUG_PLUGIN		0x20000
 
 #define	GKRELLM_FLOAT_FACTOR	1000.0
 
@@ -63,6 +65,8 @@ struct	GkrellmConfig
 	gint		demo;
 	gint		test;
 	gboolean	nolock;
+	gboolean	without_libsensors;
+	gboolean	config_clean;
 
 	gint		up_minutes;
 	gint		base_uptime;
@@ -311,6 +315,8 @@ struct	GkrellmConfig
 
 extern struct GkrellmConfig  _GK;
 
+extern GList		*gkrellm_monitor_list;
+
 extern struct tm	gkrellm_current_tm;
 extern gint			gkrellm_w_display,
 					gkrellm_h_display,
@@ -372,7 +378,7 @@ void	gkrellm_chart_setup(void);
 
 void	gkrellm_build(void);
 void	gkrellm_theme_config(void);
-void	gkrellm_load_user_config(gboolean);
+void	gkrellm_load_user_config(GkrellmMonitor *mon_only, gboolean);
 void	gkrellm_save_user_config(void);
 void	gkrellm_save_theme_config(void);
 void	gkrellm_load_theme_config(void);
@@ -389,6 +395,7 @@ void	gkrellm_inet_load_data(void);
 void	gkrellm_inet_save_data(void);
 
 void	gkrellm_net_save_data(void);
+void	gkrellm_net_server_has_timer(void);
 
 gint	gkrellm_effect_string_value(gchar *);
 
@@ -442,7 +449,8 @@ void		gkrellm_sensor_reset_location(gpointer sr);
 void		gkrellm_sensors_rebuild(gboolean do_temp, gboolean do_fan,
 						gboolean do_volt);
 void		gkrellm_sensors_model_update(void);
-void		gkrellm_sensors_interface_remove(gint interface);
+void		gkrellm_sensors_interface_remove(gint _interface);
+void		gkrellm_sensors_sysdep_option(gchar *, gchar *, void (*func)());
 
 /* pixops */
 void		gkrellm_border_adjust(GkrellmBorder *border,
@@ -472,4 +480,6 @@ void		gkrellm_client_mode_disconnect(void);
 struct tm	*gkrellm_client_server_time(void);
 gint		gkrellm_client_server_connect_state(void);
 void		gkrellm_client_mode_connect_thread(void);
+gint		gkrellm_client_server_get_net_timer(void);
+
 
