@@ -1,22 +1,22 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 /* These functions define the GKrellM interface to the system dependent
@@ -141,10 +141,11 @@ gint	gkrellm_sys_disk_order_from_name(gchar *name);
 void	gkrellm_disk_client_divert(void (*read_func)(),
 			gchar *(*name_from_device_func)(), gint (*order_from_name_func)());
 void	gkrellm_disk_assign_data_by_device(gint device_number,
-				gint unit_number, guint64 r, guint64 w);
-void	gkrellm_disk_assign_data_nth(gint n, guint64 r, guint64 w);
+				gint unit_number, guint64 r, guint64 w, gboolean virtual);
+void	gkrellm_disk_assign_data_nth(gint n, guint64 r, guint64 w,
+				gboolean virtual);
 void	gkrellm_disk_assign_data_by_name(gchar *name,
-				guint64 r, guint64 w);
+				guint64 r, guint64 w, gboolean virtual);
 void	gkrellm_disk_subdisk_assign_data_by_name(gchar *subdisk_name,
 				gchar *disk_name, guint64 r, guint64 w);
 
@@ -195,7 +196,8 @@ gchar	*gkrellm_net_mon_first(void);
 gchar	*gkrellm_net_mon_next(void);
 void	gkrellm_net_routed_event(gchar *name, gboolean routed);
 
-  /* Routines optionally called from gkrellm_sys_net_init().
+  /* Routines optionally called from gkrellm_sys_net_init()
+  *  or client_sys_net_init().
   */
 void	gkrellm_net_use_routed(gboolean);
 void	gkrellm_net_add_timer_type_ppp(gchar *);
@@ -289,6 +291,8 @@ gpointer gkrellm_sensors_add_sensor(gint type, gchar *sensor_path,
         	gint id, gint iodev, gint inter,
         	gfloat factor, gfloat offset, gchar *vref, gchar *default_label);
 void	gkrellm_sensors_set_group(gpointer sr, gint group);
+void	gkrellm_sensors_sysdep_option(gchar *keyword, gchar *label,
+			void (*func)());
 
   /* Common sensor reading from daemons.  Interfaces from 0 - 20 are available
   |  for system dependent interfaces.  Interfaces from 20 up are used here
@@ -306,3 +310,7 @@ gboolean	gkrellm_sys_sensors_mbmon_supported(void);
 gboolean	gkrellm_sys_sensors_mbmon_check(gboolean force);
 gboolean	gkrellm_sys_sensors_mbmon_get_value(gchar *name, gfloat *value);
 gboolean	gkrellm_sys_sensors_mbmon_port_change(gint port);
+
+  /* Config migration helper */
+void	gkrellm_sensors_config_migrate_connect(
+				gboolean (*config_migrate_func)(), gint sysdep_private);
