@@ -1,22 +1,22 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 #include "gkrellm.h"
@@ -647,10 +647,15 @@ GtkWidget *
 gkrellm_gtk_framed_vbox(GtkWidget *box, gchar *label, gint frame_border_width,
 		gboolean frame_expand, gint vbox_pad, gint vbox_border_width)
 	{
-	GtkWidget	*frame;
+	GtkWidget	*frame, *lbl;
 	GtkWidget	*vbox;
 
-	frame = gtk_frame_new(label);
+	frame = gtk_frame_new(NULL);
+/*	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE); */
+	lbl = gtk_label_new(NULL);
+	gtk_label_set_markup(GTK_LABEL(lbl), label);
+	gtk_frame_set_label_widget(GTK_FRAME(frame), lbl);
+
 	gtk_container_set_border_width(GTK_CONTAINER(frame), frame_border_width);
     gtk_box_pack_start(GTK_BOX(box), frame, frame_expand, frame_expand, 0);
     vbox = gtk_vbox_new(FALSE, vbox_pad);
@@ -706,7 +711,7 @@ gkrellm_gtk_category_vbox(GtkWidget *box, gchar *category_header,
 	label = gtk_label_new("    ");
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	vbox1 = gtk_vbox_new(FALSE, box_pad);
-	gtk_box_pack_start(GTK_BOX(hbox), vbox1, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), vbox1, TRUE, TRUE, 0);
 
 	/* Add some bottom pad */
 	label = gtk_label_new("");
@@ -751,8 +756,8 @@ create_about_tab(GtkWidget *vbox)
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 
 	buf = g_strdup_printf(_("GKrellM %d.%d.%d%s\nGNU Krell Monitors\n\n"
-				"Copyright (c) 1999-2004 by Bill Wilson\n"
-				"bill@gkrellm.net\n"
+				"Copyright (c) 1999-2007 by Bill Wilson\n"
+				"billw@gkrellm.net\n"
 				"http://gkrellm.net\n\n"
 				"Released under the GNU General Public License"),
 				GKRELLM_VERSION_MAJOR, GKRELLM_VERSION_MINOR,
@@ -782,6 +787,14 @@ create_about_tab(GtkWidget *vbox)
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 #endif
+#if defined(__DragonFly__)
+	buf = g_strdup_printf(
+				_("DragonFly system dependent code was contributed by:\n"
+				"Joerg Sonnenberger <joerg@bec.de>"));
+	label = gtk_label_new(buf);
+	g_free(buf);
+	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+#endif
 #if defined(__NetBSD__)
 	buf = g_strdup_printf(
 				_("NetBSD system dependent code was contributed by:\n"
@@ -801,11 +814,12 @@ create_about_tab(GtkWidget *vbox)
 #if defined(WIN32)
 	buf = g_strdup_printf(
 				_("Windows system dependent code was contributed by:\n"
-				"Bill Nalen <bill@nalens.com>"));
+				"Bill Nalen <bill@nalens.com>\n"
+				"Stefan Gehn <metz81@web.de>\n"));
 	label = gtk_label_new(buf);
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
-#endif
+#endif // !WIN32
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 	}
 
@@ -815,7 +829,10 @@ static GtkWidget
 			*enable_hst_button,
 			*hostname_short_button,
 			*enable_sysname_button,
-			*save_position_button,
+			*save_position_button;
+
+#if !defined(WIN32)
+static GtkWidget
 			*sticky_state_button,
 			*dock_type_button,
 			*decorated_button,
@@ -823,6 +840,7 @@ static GtkWidget
 			*skip_pager_button,
 			*above_button,
 			*below_button;
+#endif // !WIN32
 
 GtkWidget	*track_gtk_button,
 			*allow_multiple_button;
@@ -861,9 +879,10 @@ cb_hostname_sysname(GtkWidget *widget, gpointer data)
 static void
 cb_general(void)
 	{
-	GtkWidget	*top_window = gkrellm_get_top_window();
+#if !defined(WIN32)
 	gint		n;
 	gboolean	new_state;
+#endif
 
 	if (allow_multiple_button)
 		_GK.allow_multiple_instances =
@@ -872,6 +891,7 @@ cb_general(void)
 		_GK.on_top = GTK_TOGGLE_BUTTON(on_top_button)->active;
 
 	_GK.save_position = GTK_TOGGLE_BUTTON(save_position_button)->active;
+#if !defined(WIN32)
 	if (sticky_state_button)
 		{
 		n = GTK_TOGGLE_BUTTON(sticky_state_button)->active;
@@ -879,6 +899,8 @@ cb_general(void)
 		_GK.sticky_state = n;
 		if (new_state)
 			{
+			GtkWidget	*top_window = gkrellm_get_top_window();
+
 			if (_GK.sticky_state)
 				gtk_window_stick(GTK_WINDOW(top_window));
 			else
@@ -889,7 +911,6 @@ cb_general(void)
 	if (decorated_button)	/* restart for change to take effect */
 		_GK.decorated = GTK_TOGGLE_BUTTON(decorated_button)->active;
 
-#if !defined(WIN32)
 	if (skip_taskbar_button)
 		{
 		n = GTK_TOGGLE_BUTTON(skip_taskbar_button)->active;
@@ -932,9 +953,10 @@ cb_general(void)
 			gkrellm_winop_state_below(n);
 			}
 		}
-#endif
+#endif // !WIN32
 	}
 
+#ifndef WIN32
 static void
 cb_dock_type(GtkWidget *widget, gpointer data)
 	{
@@ -955,6 +977,7 @@ cb_dock_type(GtkWidget *widget, gpointer data)
 	gtk_widget_set_sensitive(skip_taskbar_button, sensitive);
 	gtk_widget_set_sensitive(skip_pager_button, sensitive);
 	}
+#endif // WIN32
 
 static gchar	*general_info_text[]	=
 {
@@ -1012,7 +1035,10 @@ static void
 create_general_tab(GtkWidget *tab_vbox)
 	{
 	GtkWidget		*tabs;
-	GtkWidget		*vbox, *vbox1, *vbox2;
+	GtkWidget		*vbox, *vbox1;
+#if !defined(WIN32)
+	GtkWidget		*vbox2;
+#endif
 	GtkWidget		*hbox;
 	GtkWidget		*label, *text;
 	gint			i;
@@ -1054,14 +1080,14 @@ create_general_tab(GtkWidget *tab_vbox)
 			_GK.allow_multiple_instances, FALSE, FALSE, 0,
 			cb_general, NULL,
 			_("Allow multiple instances"));
-#endif
+#endif // !WIN32
 
 #if defined(WIN32)
 	gkrellm_gtk_check_button_connected(vbox, &on_top_button,
 			_GK.on_top, FALSE, FALSE, 0,
 			cb_general, NULL,
 _("Make gkrellm a topmost window (restart gkrellm for this to take effect)."));
-#endif
+#endif // WIN32
 
 	if (_GK.client_mode)
 		{
@@ -1075,7 +1101,7 @@ _("Make gkrellm a topmost window (restart gkrellm for this to take effect)."));
 
 	vbox = gkrellm_gtk_framed_vbox_end(vbox, NULL, 4, FALSE, 0, 2);
 	gkrellm_gtk_spin_button(vbox, NULL, (gfloat) _GK.update_HZ,
-			2.0, 20.0, 1.0, 1.0, 0, 55,
+			1.0, 20.0, 1.0, 1.0, 0, 55,
 			cb_HZ_spin, NULL, FALSE,
 			_("Krell and LED updates per second."));
 
@@ -1129,7 +1155,7 @@ _("Make gkrellm a topmost window (restart gkrellm for this to take effect)."));
 _("Some of these properties require a standards compliant window manager.\n"
   "You may have to restart gkrellm for them to take effect.\n"));
 	gtk_box_pack_end(GTK_BOX(vbox), text, FALSE, TRUE, 4);
-#endif
+#endif // !WIN32
 
 /* --Info tab */
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
@@ -1526,7 +1552,7 @@ gkrellm_save_theme_config(void)
 	/* Assume gkrellm -t is for testing and don't save theme config changes.
 	|  Similary for _GK.demo.
 	*/
-	if (!theme_modified || _GK.command_line_theme || _GK.demo)
+	if (!theme_modified || _GK.command_line_theme || _GK.demo || _GK.no_config)
 		return;
 
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),
@@ -1775,6 +1801,7 @@ gkrellm_get_theme_scale(void)
 	return (gfloat) (_GK.theme_scale) / 100.0;
 	}
 
+#ifndef WIN32
 static void
 cb_track_gtk(GtkToggleButton *button, GtkWidget *box)
 	{
@@ -1791,13 +1818,17 @@ cb_track_entry_changed(GtkWidget *widget, gpointer *data)
 	gkrellm_dup_string(&_GK.default_track_theme, s);
 	gkrellm_config_modified();
 	}
+#endif // !WIN32
 
 static void
 create_theme_tab(GtkWidget *tabs_vbox)
 	{
 	GtkWidget		*tabs;
 	GtkWidget		*vbox, *vbox1, *vbox2, *hbox;
-	GtkWidget		*label, *entry;
+	GtkWidget		*label;
+#if !defined(WIN32)
+	GtkWidget		*entry;
+#endif // !WIN32
 	GtkWidget		*scrolled;
 	GtkTreeModel	*model;
 	GtkCellRenderer	*renderer;
@@ -1883,7 +1914,7 @@ create_theme_tab(GtkWidget *tabs_vbox)
 	g_signal_connect(G_OBJECT(entry), "changed",
 				G_CALLBACK(cb_track_entry_changed), NULL);
 
-#endif
+#endif // !WIN32
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
