@@ -1,22 +1,22 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 #include "gkrellm.h"
@@ -331,6 +331,16 @@ void
 gkrellm_draw_decal_text(GkrellmPanel *p, GkrellmDecal *d, gchar *s, gint value)
 	{
 	d->flags &= ~DF_TEXT_USE_MARKUP;
+
+	/* In case mixing scroll_text and draw_decal_text calls
+	*/
+	d->flags &= ~DF_SCROLL_TEXT_DIVERTED;
+	if (d->scroll_text)
+		{
+		g_free(d->scroll_text);
+		d->scroll_text = NULL;
+		}
+
 	gkrellm_draw_decal_internal(p, d, s, value);
 	}
 
@@ -338,6 +348,16 @@ void
 gkrellm_draw_decal_markup(GkrellmPanel *p, GkrellmDecal *d, gchar *s)
 	{
 	d->flags |= DF_TEXT_USE_MARKUP;
+
+	/* In case mixing scroll_text and draw_decal_text calls
+	*/
+	d->flags &= ~DF_SCROLL_TEXT_DIVERTED;
+	if (d->scroll_text)
+		{
+		g_free(d->scroll_text);
+		d->scroll_text = NULL;
+		}
+
 	gkrellm_draw_decal_internal(p, d, s, 0);
 	}
 
@@ -608,6 +628,24 @@ decal_scroll_text_layout(GkrellmDecal *d, gchar *text, gint *yink)
 	return layout;
 	}
 
+  /* If mixing draw_decal_text and scroll_text calls, must reset decal regions
+  |  in bg_text_layer_pixmap to bg_pixmap at first switch to scroll_text calls.
+  */
+static void
+reset_text_layer_pixmap_decal_region(GkrellmPanel *p, GkrellmDecal *d)
+	{
+	if (d->flags & DF_MOVED)
+		{
+		gdk_draw_drawable(p->bg_text_layer_pixmap, _GK.draw1_GC,
+					p->bg_pixmap,
+					d->x_old, d->y_old, d->x_old, d->y_old, d->w, d->h);
+		d->flags &= ~DF_MOVED;
+		}
+	else
+		gdk_draw_drawable(p->bg_text_layer_pixmap, _GK.draw1_GC,
+					p->bg_pixmap,
+					d->x, d->y,  d->x, d->y,   d->w, d->h);
+	}
 
   /* Draw Pango rendered text onto a pixmap which can be scrolled across
   |  a decal's extents.  So when scrolling, a slow Pango redraw at each scroll
@@ -636,11 +674,13 @@ gkrellm_decal_scroll_text_set_internal(GkrellmPanel *p, GkrellmDecal *d,
 	GkrellmBorder		*b;
 	GkrellmTextstyle	*ts;
 	gint				dx, y_ink;
-	gboolean			new_text, no_scroll_caching;
+	gboolean			new_text, no_scroll_caching, first_scroll;
 
 	if (!p || !text || !d || d->state == DS_INVISIBLE)
 		return;
 
+	first_scroll = (d->scroll_text == NULL);
+
 	new_text = gkrellm_dup_string(&d->scroll_text, text);
 	no_scroll_caching = (p->transparency || p->scroll_text_cache_off);
 
@@ -663,30 +703,22 @@ gkrellm_decal_scroll_text_set_internal(GkrellmPanel *p, GkrellmDecal *d,
 			   )
 		   )
 			{
+			if (first_scroll && d->text_list)
+				reset_text_layer_pixmap_decal_region(p, d);
+
 			d->flags |= (DF_TEXT_OVERLAPS | DF_SCROLL_TEXT_DIVERTED);
 			if (new_text)
 				{
 				layout = decal_scroll_text_layout(d, text, NULL);
 				g_object_unref(G_OBJECT(layout));
 				}
-			gkrellm_draw_decal_text(p, d, text, -1);
+			gkrellm_draw_decal_internal(p, d, text, -1);
 			return;
 			}
 		}
 	if (d->text_list)	/* Erase any previous gkrellm_draw_decal_text()	*/
 		{
-		if (d->flags & DF_MOVED)
-			{
-			gdk_draw_drawable(p->bg_text_layer_pixmap, _GK.draw1_GC,
-						p->bg_pixmap,
-						d->x_old, d->y_old, d->x_old, d->y_old, d->w, d->h);
-			d->flags &= ~DF_MOVED;
-			}
-		else
-			gdk_draw_drawable(p->bg_text_layer_pixmap, _GK.draw1_GC,
-						p->bg_pixmap,
-						d->x, d->y,  d->x, d->y,   d->w, d->h);
-
+		reset_text_layer_pixmap_decal_region(p, d);
 		decal_text_list_free(&d->text_list);
 		d->value = -1;
 		}
@@ -759,6 +791,8 @@ void
 gkrellm_decal_scroll_text_set_markup(GkrellmPanel *p, GkrellmDecal *d,
 			gchar *text)
 	{
+	if (!d)
+		return;
 	d->flags |= DF_TEXT_USE_MARKUP;
 	gkrellm_decal_scroll_text_set_internal(p, d, text);
 	}
@@ -767,6 +801,8 @@ void
 gkrellm_decal_scroll_text_set_text(GkrellmPanel *p, GkrellmDecal *d,
 			gchar *text)
 	{
+	if (!d)
+		return;
 	d->flags &= ~DF_TEXT_USE_MARKUP;
 	gkrellm_decal_scroll_text_set_internal(p, d, text);
 	}
