@@ -1,22 +1,22 @@
 /* GKrellM
-|  Copyright (C) 1999-2006 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 #include "gkrellm.h"
@@ -265,7 +265,8 @@ set_or_save_position(gint save)
 			gdk_window_get_position(top_window->window,
 					&_GK.x_position, &_GK.y_position);
 			}
-		if (   (_GK.x_position != x_last || _GK.y_position != y_last)
+		if (   !_GK.no_config
+		    && (_GK.x_position != x_last || _GK.y_position != y_last)
 			&& (f = fopen(path, "w")) != NULL
 		   )
 			{
@@ -614,8 +615,8 @@ top_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 	time_t			time_check;
 
 	gdk_window_get_pointer(NULL, &x_pointer, &y_pointer, &m);
-	gdk_window_get_geometry(NULL, NULL, NULL, &_GK.w_display,
-				&_GK.h_display, NULL);
+	_GK.w_display = gdk_screen_get_width(gdk_screen_get_default());
+	_GK.h_display = gdk_screen_get_height(gdk_screen_get_default());
 	gkrellm_width = _GK.chart_width
 				+ _GK.frame_left_width + _GK.frame_right_width;
 	gkrellm_height = _GK.monitor_height + _GK.total_frame_height;
@@ -760,6 +761,8 @@ side_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 			gtk_widget_show(gtree.middle_vbox);
 			gtk_widget_show(gtree.top0_vbox);
 			gtk_widget_show(gtree.bottom_vbox);
+			while (gtk_events_pending())
+				gtk_main_iteration ();
 			if (direction == CLOSE_RIGHT)
 				gdk_window_move(gtree.window->window,
 								x_gkrell - _GK.chart_width, y_gkrell);
@@ -769,6 +772,8 @@ side_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 			gtk_widget_hide(gtree.top0_vbox);
 			gtk_widget_hide(gtree.bottom_vbox);
 			gtk_widget_hide(gtree.middle_vbox);
+			while (gtk_events_pending())
+				gtk_main_iteration ();
 			if (direction == CLOSE_RIGHT)
 				gdk_window_move(gtree.window->window,
 								x_gkrell + _GK.chart_width, y_gkrell);
@@ -1612,8 +1617,8 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 	gint        x, y, w, h, w_gkrellm, h_gkrellm;
 	static gint	x_prev, y_prev, w_prev, h_prev;
 
-	gdk_window_get_geometry(NULL, NULL, NULL, &_GK.w_display,
-				&_GK.h_display, NULL);
+	_GK.w_display = gdk_screen_get_width(gdk_screen_get_default());
+	_GK.h_display = gdk_screen_get_height(gdk_screen_get_default());
 
 #if !defined(WIN32)
 	gdk_window_get_position(widget->window, &x, &y);
@@ -1757,46 +1762,58 @@ cb_destroy_event()
 	gtk_main_quit();
 	}
 
-static gchar	*usage_string =
+static gchar	*usage_string[] =
+{
 N_("usage: gkrellm [options]\n"
-"options:\n"
-"   -t, --theme theme_dir    Select a theme directory.\n"
-"   -g, --geometry +x+y      Position the window on the screen.\n"
-"       --wm                 Allow window manager decorations.\n"
-"       --m2                 Left button side frame shading (for 2 btn mice).\n"
-"       --nt                 No transparency.\n"
-"   -w, --withdrawn          Draw GKrellM in withdrawn mode.\n"
-"   -c, --config suffix      Use alternate config files generated by\n"
-"                            appending \"suffix\" to config file names.\n"
-"   -f, --force-host-config  Creates config files generated by appending the\n"
-"                            hostname to config file names.  Subsequent runs\n"
-"                            automatically will use these configs unless a\n"
-"                            specific config is specified with --config.\n"
-"                            This is a convenience for allowing remote runs\n"
-"                            with independent configs in a shared home dir\n"
-"                            and for the hostname to be in the window title.\n"
-"                            This option has no effect in client mode.\n"
-"   -s, --server hostname    Run in client mode: connect to \"hostname\" and\n"
-"                            read monitor data from a gkrellmd server.\n"
-"   -P, --port server_port   Use \"server_port\" for the server connection.\n"
-"       --nc                 No config mode prevents configuration changes.\n"
-"   -p, --plugin plugin.so   While developing, load your plugin under test.\n"
-"       --demo               Force enabling of many monitors so themers can\n"
-"                            see everything. All config saving is inhibited.\n"
-"   -v, --version            Print GKrellM version number and exit.\n"
-"   -d, --debug-level n      Turn debugging on for selective code sections.\n"
+   "options:\n"),
+N_("   -t, --theme theme_dir    Select a theme directory.\n"),
+N_("   -g, --geometry +x+y      Position the window on the screen.\n"),
+N_("       --wm                 Allow window manager decorations.\n"),
+N_("       --m2                 Left button side frame shading (for 2 btn mice).\n"),
+N_("       --nt                 No transparency.\n"),
+N_("   -w, --withdrawn          Draw GKrellM in withdrawn mode.\n"),
+N_("   -c, --config suffix      Use alternate config files generated by\n"
+   "                            appending \"suffix\" to config file names.\n"),
+N_("   -f, --force-host-config  Creates config files generated by appending the\n"
+   "                            hostname to config file names.  Subsequent runs\n"
+   "                            automatically will use these configs unless a\n"
+   "                            specific config is specified with --config.\n"
+   "                            This is a convenience for allowing remote runs\n"
+   "                            with independent configs in a shared home dir\n"
+   "                            and for the hostname to be in the window title.\n"
+   "                            This option has no effect in client mode.\n"),
+N_("   -s, --server hostname    Run in client mode: connect to \"hostname\" and\n"
+   "                            read monitor data from a gkrellmd server.\n"),
+N_("   -P, --port server_port   Use \"server_port\" for the server connection.\n"),
+N_("       --nc                 No config mode prevents configuration changes.\n"),
+N_("       --config-clean       Clean out unused configs on config write.\n"),
+N_("       --nolock             Allow multiple gkrellm instances.\n"),
+N_("   -p, --plugin plugin.so   While developing, load your plugin under test.\n"),
+N_("       --demo               Force enabling of many monitors so themers can\n"
+   "                            see everything. All config saving is inhibited.\n"),
+N_("   -v, --version            Print GKrellM version number and exit.\n"),
+N_("   -d, --debug-level n      Turn debugging on for selective code sections.\n"),
 
-"\ndebug-level numbers are (bitwise OR to debug multiple sections):\n"
-"     0x10  mail\n"
-"     0x20  net\n"
-"     0x40  timer button\n"
-"     0x80  sensors\n\n"
-);
+N_("\ndebug-level numbers are (bitwise OR to debug multiple sections):\n"
+"     0x10    mail\n"
+"     0x20    net\n"
+"     0x40    timer button\n"
+"     0x80    sensors\n"
+"     0x800   inet\n"
+"     0x1000  dump gkrellmd server data\n"
+"     0x2000  GUI\n"
+"     0x8000  battery\n"
+"     0x20000 plugin \n"
+"\n")
+};
 
 static void
 usage()
 	{
-	g_print(_(usage_string));
+	gint	i;
+
+	for (i = 0; i < sizeof(usage_string) / sizeof(gchar *); ++i)
+		g_print(_(usage_string[i]));
 	}
 
 
@@ -1827,7 +1844,7 @@ gkrellm_build()
 
 	gkrellm_theme_config();
 	if (first_create)
-		gkrellm_load_user_config(TRUE);
+		gkrellm_load_user_config(NULL, TRUE);
 	setup_colors();
 	setup_fonts();
 	gkrellm_load_theme_piximages();
@@ -2019,35 +2036,20 @@ gkrellm_abort(gint sig)
 static void
 setup_signal_handler(void)
 	{
+#ifndef WIN32
 	signal(SIGPIPE, SIG_IGN);
-	signal(SIGINT, _signal_quit);
 	signal(SIGQUIT, _signal_quit);
+#endif
+	signal(SIGINT, _signal_quit);
 	signal(SIGTERM, _signal_quit);
 	}
 
 
-#if defined(WIN32) && defined(_WINDOWS)
-int APIENTRY WinMain(HINSTANCE	hInstance,
-					HINSTANCE	hPrevInstance,
-					LPSTR		lpCmdLine,
-					int			nCmdShow)
-	{
-	int		argc;
-	gint	i;
-	gchar	*s, *sm;
-	gchar	**argv;
-	gchar	*cmd;
-
-	// need to get exe too
-	cmd = GetCommandLine();
-	g_shell_parse_argv(cmd, &argc, &argv, NULL);
-#else
 gint
 main(gint argc, gchar **argv)
 	{
 	gint		i;
 	gchar		*s;
-#endif
 
 	gkrellm_sys_main_init();
 
@@ -2135,6 +2137,13 @@ main(gint argc, gchar **argv)
 			}
 		else if (!strcmp(s, "nolock"))
 			_GK.nolock = TRUE;
+		else if (!strcmp(s, "without-libsensors"))
+			_GK.without_libsensors = TRUE;
+		else if (!strcmp(s, "config-clean"))
+			{
+			_GK.config_clean = TRUE;
+			_GK.config_modified = TRUE;
+			}
 		else if (!strcmp(s, "demo"))
 			++_GK.demo;
 		else if (!strcmp(s, "test"))
@@ -2158,8 +2167,9 @@ main(gint argc, gchar **argv)
 			exit(0);
 			}
 		}
-	gdk_window_get_geometry(NULL /*gdk_root_parent*/, &i, &i, &_GK.w_display,
-				&_GK.h_display, &i);
+
+	_GK.w_display = gdk_screen_get_width(gdk_screen_get_default());
+	_GK.h_display = gdk_screen_get_height(gdk_screen_get_default());
 
 	if (_GK.debug_level)
 		printf("--- GKrellM %d.%d.%d ---\n", GKRELLM_VERSION_MAJOR,
@@ -2168,7 +2178,7 @@ main(gint argc, gchar **argv)
 		exit(0);
 
 	check_gkrellm_directories();
-	gkrellm_load_user_config(FALSE);		
+	gkrellm_load_user_config(NULL, FALSE);		
 	decorated = (_GK.command_line_decorated || _GK.decorated);
 	if (   _GK.command_line_plugin || _GK.command_line_theme
 		|| _GK.debug_level > 0 || _GK.debug > 0 || _GK.nolock
@@ -2246,9 +2256,29 @@ main(gint argc, gchar **argv)
 	gkrellm_save_all();
 	gkrellm_exit(0);
 
-#if defined(_WINDOWS)
-    g_strfreev(argv);
-#endif
-
 	return 0;
 	}
+
+
+#if defined(WIN32) && defined(_WINDOWS)
+int APIENTRY WinMain(HINSTANCE	hInstance,
+					HINSTANCE	hPrevInstance,
+					LPSTR		lpCmdLine,
+					int			nCmdShow)
+	{
+	int		argc;
+	gint	i, ret;
+	gchar	*s, *sm;
+	gchar	**argv;
+	gchar	*cmd;
+
+	// need to get exe too
+	cmd = GetCommandLine();
+	g_shell_parse_argv(cmd, &argc, &argv, NULL);
+
+	ret = main(argc, argv);
+    g_strfreev(argv);
+	return ret;
+	}
+#endif
+
